import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:conalep_pos/themes/themes.dart';
import 'package:intl/intl.dart';
import '../../viewmodels/corte_caja_view_model.dart';
import '../../widgets/widgets.dart';

class CorteCajaForm extends StatefulWidget {
  final String? corteCajaId;

  const CorteCajaForm({this.corteCajaId, Key? key}) : super(key: key);

  @override
  _CorteCajaFormState createState() => _CorteCajaFormState();
}

class _CorteCajaFormState extends State<CorteCajaForm> {
  final TextEditingController _fondoController = TextEditingController();
  final TextEditingController _fondoDiaSigContr = TextEditingController();
  final TextEditingController _ventaEfeContr = TextEditingController();
  final TextEditingController _ventaTarjContr = TextEditingController();
  final TextEditingController _ventaTransfContr = TextEditingController();
  final TextEditingController _totalVentaContr = TextEditingController();
  final TextEditingController _gastosContr = TextEditingController();
  final TextEditingController _montoDepositoController =
      TextEditingController();
  final TextEditingController _montoRetiroController = TextEditingController();
  final TextEditingController _descripcionDepositoController =
      TextEditingController();
  final TextEditingController _descripcionRetiroController =
      TextEditingController();
  final TextEditingController _personaDepositoContr = TextEditingController();
  final TextEditingController _personaRetiroContr = TextEditingController();

  bool showDepositoPanel = false;
  bool showRetiroPanel = false;

  @override
  void initState() {
    super.initState();
    if (widget.corteCajaId != null) {
      Provider.of<CorteCajaViewModel>(context, listen: false)
          .fetchDepositosAndRetiros(widget.corteCajaId!);
    }
  }

  @override
  Widget build(BuildContext context) {
    final viewModel = Provider.of<CorteCajaViewModel>(context);

    return Scaffold(
      appBar: AppBar(
        title: Text('Corte de Caja Conalep',
            style: TextStyle(color: AppTheme.quaternary)),
        iconTheme: IconThemeData(color: AppTheme.quaternary),
      ),
      body: Column(children: [
        Container(
          padding: EdgeInsets.symmetric(horizontal: 50, vertical: 20),
          width: MediaQuery.of(context).size.width,
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Expanded(
                flex: 4,
                child: _buildFormContent(context, viewModel),
              ),
              SizedBox(width: 80),
              Expanded(
                flex: 3,
                child: Column(
                  children: [
                    if (showDepositoPanel) _buildDepositoPanel(viewModel),
                    if (showRetiroPanel) _buildRetiroPanel(viewModel),
                  ],
                ),
              ),
            ],
          ),
        )
      ]),
    );
  }

  Widget _buildFormContent(BuildContext context, CorteCajaViewModel viewModel) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          "Fecha: ${DateFormat('dd/MM/yyyy').format(DateTime.now())}",
          style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
        ),
        SizedBox(height: 20),
        tarjeta(
          Table(
            defaultVerticalAlignment: TableCellVerticalAlignment.middle,
            columnWidths: {0: FlexColumnWidth(4), 1: FlexColumnWidth(2)},
            children: [
              _buildTableRow("Fondo", _fondoController),
              _buildDepositoRow(viewModel),
              _buildTableRow("Fondo día siguiente", _fondoDiaSigContr),
              _buildTableRow("Ventas efectivo", _ventaEfeContr),
              _buildTableRow("Ventas tarjeta", _ventaTarjContr),
              _buildTableRow("Ventas transferencia", _ventaTransfContr),
              _buildTableRow("Total ventas", _totalVentaContr),
              _buildRetiroRow(viewModel),
              _buildTableRow("Gastos del día", _gastosContr),
              _buildCorteFinalRow(viewModel),
            ],
          ),
        ),
        SizedBox(height: 20),
        Center(
          child: ElevatedButton(
            onPressed: () {
              viewModel.calcularCorteFinal(
                double.tryParse(_fondoController.text) ?? 0,
                double.tryParse(_fondoDiaSigContr.text) ?? 0,
                double.tryParse(_totalVentaContr.text) ?? 0,
              );
            },
            child:
                Text('Finalizar', style: TextStyle(color: AppTheme.quaternary)),
            style: ElevatedButton.styleFrom(
              primary: AppTheme.primary,
              padding: EdgeInsets.symmetric(horizontal: 50, vertical: 15),
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(10),
              ),
            ),
          ),
        ),
      ],
    );
  }

  TableRow _buildTableRow(String label, TextEditingController controller) {
    return TableRow(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          padding: const EdgeInsets.all(11.5),
          child: Text(label, style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          height: 45,
          padding: const EdgeInsets.all(8.0),
          child: TextField(
            controller: controller,
            keyboardType: TextInputType.number,
            decoration: InputDecoration(
              hintText: "\$",
              border: InputBorder.none,
              contentPadding: EdgeInsets.symmetric(vertical: 8, horizontal: 12),
            ),
          ),
        ),
      ],
    );
  }

  TableRow _buildDepositoRow(CorteCajaViewModel viewModel) {
    return TableRow(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          padding: const EdgeInsets.all(11.5),
          child:
              Text("Depósitos", style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          height: 45, // Ajuste de altura fija
          child: Row(
            children: [
              Expanded(
                child: Container(
                  alignment: Alignment.center,
                  padding: EdgeInsets.symmetric(horizontal: 12),
                  child:
                      Text("\$${viewModel.totalDepositos.toStringAsFixed(2)}"),
                ),
              ),
              IconButton(
                icon: Icon(Icons.add, color: AppTheme.primary),
                onPressed: () {
                  setState(() {
                    showDepositoPanel = true;
                    showRetiroPanel = false;
                  });
                },
              ),
            ],
          ),
        ),
      ],
    );
  }

  TableRow _buildRetiroRow(CorteCajaViewModel viewModel) {
    return TableRow(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          padding: const EdgeInsets.all(11.5),
          child: Text("Retiros", style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          height: 45,
          child: Row(
            children: [
              Expanded(
                child: Container(
                  alignment: Alignment.center,
                  padding: EdgeInsets.symmetric(horizontal: 12),
                  child: Text("\$${viewModel.totalRetiros.toStringAsFixed(2)}"),
                ),
              ),
              IconButton(
                icon: Icon(Icons.add, color: AppTheme.primary),
                onPressed: () {
                  setState(() {
                    showRetiroPanel = true;
                    showDepositoPanel = false;
                  });
                },
              ),
            ],
          ),
        ),
      ],
    );
  }

  Widget _buildDepositoPanel(CorteCajaViewModel viewModel) {
    return tarjeta(
      Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            "Depósitos",
            style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
          ),
          SizedBox(height: 10),
          TextField(
            controller: _montoDepositoController,
            decoration: InputDecoration(
              labelText: "Monto del depósito",
              border: OutlineInputBorder(),
            ),
            keyboardType: TextInputType.number,
          ),
          SizedBox(height: 10),
          TextField(
            controller: _descripcionDepositoController,
            decoration: InputDecoration(
              labelText: "Descripción del depósito",
              border: OutlineInputBorder(),
            ),
          ),
          SizedBox(height: 10),
          TextField(
            controller: _personaDepositoContr,
            decoration: InputDecoration(
              labelText: "Persona",
              border: OutlineInputBorder(),
            ),
          ),
          SizedBox(height: 20),
          // Lista de depósitos
          Text("Lista de Depósitos",
              style: TextStyle(fontWeight: FontWeight.bold)),
          ListView.builder(
            shrinkWrap: true,
            itemCount: viewModel.depositos.length,
            itemBuilder: (context, index) {
              final deposito = viewModel.depositos[index];
              if (deposito.eliminado == null) {
                return ListTile(
                  title: Text(
                      "\$${deposito.monto?.toStringAsFixed(2)} - ${deposito.descripcion}"),
                  trailing: IconButton(
                    icon: Icon(Icons.remove_circle_outline, color: Colors.red),
                    onPressed: () {
                      viewModel.eliminarDeposito(deposito.id!);
                    },
                  ),
                );
              }
              return SizedBox.shrink();
            },
          ),
          Align(
            alignment: Alignment.centerRight,
            child: Text(
                "Total: \$${viewModel.totalDepositos.toStringAsFixed(2)}",
                style: TextStyle(fontWeight: FontWeight.bold)),
          ),
          SizedBox(height: 20),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              ElevatedButton(
                onPressed: () {
                  double monto =
                      double.tryParse(_montoDepositoController.text) ?? 0;
                  String descripcion = _descripcionDepositoController.text;
                  String persona = _personaDepositoContr.text;

                  viewModel.addDeposito(
                      monto, descripcion, persona, widget.corteCajaId!);
                  _montoDepositoController.clear();
                  _descripcionDepositoController.clear();
                  _personaDepositoContr.clear();
                },
                child: Text(
                  "Agregar",
                  style: TextStyle(color: AppTheme.quaternary),
                ),
                style: ElevatedButton.styleFrom(
                  backgroundColor: AppTheme.primary,
                  padding: EdgeInsets.symmetric(horizontal: 50, vertical: 15),
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                ),
              ),
              ElevatedButton(
                onPressed: () {
                  setState(() {
                    showDepositoPanel = false;
                  });
                },
                child: Text(
                  "Finalizar",
                  style: TextStyle(color: AppTheme.quaternary),
                ),
                style: ElevatedButton.styleFrom(
                  backgroundColor: AppTheme.primary,
                  padding: EdgeInsets.symmetric(horizontal: 50, vertical: 15),
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }

  Widget _buildRetiroPanel(CorteCajaViewModel viewModel) {
    return tarjeta(
      Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            "Retiros",
            style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
          ),
          SizedBox(height: 10),
          TextField(
            controller: _montoRetiroController,
            decoration: InputDecoration(
              labelText: "Monto del retiro",
              border: OutlineInputBorder(),
            ),
            keyboardType: TextInputType.number,
          ),
          SizedBox(height: 10),
          TextField(
            controller: _descripcionRetiroController,
            decoration: InputDecoration(
              labelText: "Descripción del depósito",
              border: OutlineInputBorder(),
            ),
          ),
          SizedBox(height: 10),
          TextField(
            controller: _personaRetiroContr,
            decoration: InputDecoration(
              labelText: "Persona",
              border: OutlineInputBorder(),
            ),
          ),
          SizedBox(height: 20),
          // Lista de depósitos
          Text("Lista de Retiros",
              style: TextStyle(fontWeight: FontWeight.bold)),
          ListView.builder(
            shrinkWrap: true,
            itemCount: viewModel.retiros.length,
            itemBuilder: (context, index) {
              final retiro = viewModel.retiros[index];
              if (retiro.eliminado == null) {
                return ListTile(
                  title: Text(
                      "\$${retiro.monto?.toStringAsFixed(2)} - ${retiro.descripcion}"),
                  trailing: IconButton(
                    icon: Icon(Icons.remove_circle_outline, color: Colors.red),
                    onPressed: () {
                      viewModel.eliminarRetiro(retiro.id!);
                    },
                  ),
                );
              }
              return SizedBox.shrink();
            },
          ),
          Align(
            alignment: Alignment.centerRight,
            child: Text("Total: \$${viewModel.totalRetiros.toStringAsFixed(2)}",
                style: TextStyle(fontWeight: FontWeight.bold)),
          ),
          SizedBox(height: 20),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              ElevatedButton(
                onPressed: () {
                  double monto =
                      double.tryParse(_montoRetiroController.text) ?? 0;
                  String descripcion = _descripcionRetiroController.text;
                  String persona = _personaRetiroContr.text;

                  viewModel.addRetiro(
                      monto, descripcion, persona, widget.corteCajaId!);
                  _montoRetiroController.clear();
                  _descripcionRetiroController.clear();
                },
                child: Text(
                  "Agregar",
                  style: TextStyle(color: AppTheme.quaternary),
                ),
                style: ElevatedButton.styleFrom(
                  backgroundColor: AppTheme.primary,
                  padding: EdgeInsets.symmetric(horizontal: 50, vertical: 15),
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                ),
              ),
              ElevatedButton(
                onPressed: () {
                  setState(() {
                    showRetiroPanel = false;
                  });
                },
                child: Text(
                  "Finalizar",
                  style: TextStyle(color: AppTheme.quaternary),
                ),
                style: ElevatedButton.styleFrom(
                  backgroundColor: AppTheme.primary,
                  padding: EdgeInsets.symmetric(horizontal: 50, vertical: 15),
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }

  TableRow _buildCorteFinalRow(CorteCajaViewModel viewModel) {
    return TableRow(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          padding: EdgeInsets.all(11.5),
          child: Text("Corte Final",
              style: TextStyle(fontWeight: FontWeight.bold)),
        ),
        Container(
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey),
          ),
          height: 45, // Ajuste de altura fija
          padding: const EdgeInsets.all(8.0),
          child: Text("\$${viewModel.corteFinal.toStringAsFixed(2)}",
              style: TextStyle(fontWeight: FontWeight.bold)),
        ),
      ],
    );
  }
}
